Weekday enum

Represents days of the week.

Used to configure the first day of the week for the calendar display.

Inheritance
Available extensions

Values

sunday → const Weekday

Sunday

monday → const Weekday

Monday

tuesday → const Weekday

Tuesday

wednesday → const Weekday

Wednesday

thursday → const Weekday

Thursday

friday → const Weekday

Friday

saturday → const Weekday

Saturday

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Weekday>
A constant List of the values in this enum, in order of their declaration.