EventCalendarEssential class abstract

Abstract base class for calendar events.

Implement this class to create custom event types for the calendar. Each event must provide methods to build its visual representation and determine its selection state.

Implementers

Constructors

EventCalendarEssential(DateTime date)
Creates an event for the specified date

Properties

date DateTime
The date of this event
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildEvent(bool isSelected, bool isToday) Widget
Builds the visual representation of the event for a given day cell.
buildMarkerEvent() Widget
Builds a marker widget displayed below the day number.
isEventSelected(DateTime selectedDay) bool
Determines if this event should be shown as selected.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited