SimpleEventCalendarEssential constructor

SimpleEventCalendarEssential(
  1. CalendarStyle _calendarStyle,
  2. DateTime date,
  3. bool defaultEvent
)

Creates a simple event with the given calendar style.

_calendarStyle - The style to use for rendering this event date - The date of this event defaultEvent - If true, no marker is shown; if false, a red dot marker is displayed

Implementation

SimpleEventCalendarEssential(
    this._calendarStyle, DateTime date, this.defaultEvent)
    : super(date);