SimpleEventCalendarEssential class

Inheritance

Constructors

SimpleEventCalendarEssential(CalendarStyle _calendarStyle, DateTime date, bool defaultEvent)

Properties

date DateTime
getter/setter pairinherited
defaultEvent bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isSelected bool
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildEvent(bool isSelected, bool isToday) Widget
override
buildMarkerEvent() Widget
override
isEventSelected(DateTime selectedDay) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited